# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/image.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from is_msgs import common_pb2 as is__msgs_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/image.proto',
  package='is.vision',
  syntax='proto3',
  serialized_pb=_b('\n\x13is_msgs/image.proto\x12\tis.vision\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x14is_msgs/common.proto\"1\n\x05Image\x12\x0e\n\x04\x64\x61ta\x18\x01 \x01(\x0cH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x42\t\n\x07\x63ontent\"h\n\x0bImageFormat\x12\'\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x17.is.vision.ImageFormats\x12\x30\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\x1e\n\x06Vertex\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\"3\n\x0c\x42oundingPoly\x12#\n\x08vertices\x18\x01 \x03(\x0b\x32\x11.is.vision.Vertex\"+\n\nResolution\x12\x0e\n\x06height\x18\x01 \x01(\r\x12\r\n\x05width\x18\x02 \x01(\r\"3\n\nColorSpace\x12%\n\x05value\x18\x01 \x01(\x0e\x32\x16.is.vision.ColorSpaces\"\xb7\x01\n\rImageSettings\x12)\n\nresolution\x18\x01 \x01(\x0b\x32\x15.is.vision.Resolution\x12&\n\x06\x66ormat\x18\x02 \x01(\x0b\x32\x16.is.vision.ImageFormat\x12*\n\x0b\x63olor_space\x18\x03 \x01(\x0b\x32\x15.is.vision.ColorSpace\x12\'\n\x06region\x18\x04 \x01(\x0b\x32\x17.is.vision.BoundingPoly\"w\n\x0fImageAnnotation\x12\r\n\x05label\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12\'\n\x06region\x18\x03 \x01(\x0b\x32\x17.is.vision.BoundingPoly\x12\x1d\n\x04pose\x18\x04 \x01(\x0b\x32\x0f.is.common.Pose\"C\n\x10ImageAnnotations\x12/\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32\x1a.is.vision.ImageAnnotation*+\n\x0cImageFormats\x12\x07\n\x03PNG\x10\x00\x12\x08\n\x04JPEG\x10\x01\x12\x08\n\x04WebP\x10\x02*4\n\x0b\x43olorSpaces\x12\x07\n\x03RGB\x10\x00\x12\x08\n\x04GRAY\x10\x01\x12\t\n\x05YCbCr\x10\x02\x12\x07\n\x03HSV\x10\x03\x42\x11\n\rcom.is.visionP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,is__msgs_dot_common__pb2.DESCRIPTOR,])

_IMAGEFORMATS = _descriptor.EnumDescriptor(
  name='ImageFormats',
  full_name='is.vision.ImageFormats',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PNG', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JPEG', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WebP', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=804,
  serialized_end=847,
)
_sym_db.RegisterEnumDescriptor(_IMAGEFORMATS)

ImageFormats = enum_type_wrapper.EnumTypeWrapper(_IMAGEFORMATS)
_COLORSPACES = _descriptor.EnumDescriptor(
  name='ColorSpaces',
  full_name='is.vision.ColorSpaces',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RGB', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GRAY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YCbCr', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HSV', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=849,
  serialized_end=901,
)
_sym_db.RegisterEnumDescriptor(_COLORSPACES)

ColorSpaces = enum_type_wrapper.EnumTypeWrapper(_COLORSPACES)
PNG = 0
JPEG = 1
WebP = 2
RGB = 0
GRAY = 1
YCbCr = 2
HSV = 3



_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='is.vision.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='is.vision.Image.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='is.vision.Image.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='is.vision.Image.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=88,
  serialized_end=137,
)


_IMAGEFORMAT = _descriptor.Descriptor(
  name='ImageFormat',
  full_name='is.vision.ImageFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='is.vision.ImageFormat.format', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compression', full_name='is.vision.ImageFormat.compression', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=243,
)


_VERTEX = _descriptor.Descriptor(
  name='Vertex',
  full_name='is.vision.Vertex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='is.vision.Vertex.x', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='is.vision.Vertex.y', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=275,
)


_BOUNDINGPOLY = _descriptor.Descriptor(
  name='BoundingPoly',
  full_name='is.vision.BoundingPoly',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vertices', full_name='is.vision.BoundingPoly.vertices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=328,
)


_RESOLUTION = _descriptor.Descriptor(
  name='Resolution',
  full_name='is.vision.Resolution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='is.vision.Resolution.height', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width', full_name='is.vision.Resolution.width', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=373,
)


_COLORSPACE = _descriptor.Descriptor(
  name='ColorSpace',
  full_name='is.vision.ColorSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='is.vision.ColorSpace.value', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=426,
)


_IMAGESETTINGS = _descriptor.Descriptor(
  name='ImageSettings',
  full_name='is.vision.ImageSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resolution', full_name='is.vision.ImageSettings.resolution', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='is.vision.ImageSettings.format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color_space', full_name='is.vision.ImageSettings.color_space', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region', full_name='is.vision.ImageSettings.region', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=612,
)


_IMAGEANNOTATION = _descriptor.Descriptor(
  name='ImageAnnotation',
  full_name='is.vision.ImageAnnotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='is.vision.ImageAnnotation.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='is.vision.ImageAnnotation.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region', full_name='is.vision.ImageAnnotation.region', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pose', full_name='is.vision.ImageAnnotation.pose', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=733,
)


_IMAGEANNOTATIONS = _descriptor.Descriptor(
  name='ImageAnnotations',
  full_name='is.vision.ImageAnnotations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='annotations', full_name='is.vision.ImageAnnotations.annotations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=735,
  serialized_end=802,
)

_IMAGE.oneofs_by_name['content'].fields.append(
  _IMAGE.fields_by_name['data'])
_IMAGE.fields_by_name['data'].containing_oneof = _IMAGE.oneofs_by_name['content']
_IMAGE.oneofs_by_name['content'].fields.append(
  _IMAGE.fields_by_name['uri'])
_IMAGE.fields_by_name['uri'].containing_oneof = _IMAGE.oneofs_by_name['content']
_IMAGEFORMAT.fields_by_name['format'].enum_type = _IMAGEFORMATS
_IMAGEFORMAT.fields_by_name['compression'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_BOUNDINGPOLY.fields_by_name['vertices'].message_type = _VERTEX
_COLORSPACE.fields_by_name['value'].enum_type = _COLORSPACES
_IMAGESETTINGS.fields_by_name['resolution'].message_type = _RESOLUTION
_IMAGESETTINGS.fields_by_name['format'].message_type = _IMAGEFORMAT
_IMAGESETTINGS.fields_by_name['color_space'].message_type = _COLORSPACE
_IMAGESETTINGS.fields_by_name['region'].message_type = _BOUNDINGPOLY
_IMAGEANNOTATION.fields_by_name['region'].message_type = _BOUNDINGPOLY
_IMAGEANNOTATION.fields_by_name['pose'].message_type = is__msgs_dot_common__pb2._POSE
_IMAGEANNOTATIONS.fields_by_name['annotations'].message_type = _IMAGEANNOTATION
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
DESCRIPTOR.message_types_by_name['ImageFormat'] = _IMAGEFORMAT
DESCRIPTOR.message_types_by_name['Vertex'] = _VERTEX
DESCRIPTOR.message_types_by_name['BoundingPoly'] = _BOUNDINGPOLY
DESCRIPTOR.message_types_by_name['Resolution'] = _RESOLUTION
DESCRIPTOR.message_types_by_name['ColorSpace'] = _COLORSPACE
DESCRIPTOR.message_types_by_name['ImageSettings'] = _IMAGESETTINGS
DESCRIPTOR.message_types_by_name['ImageAnnotation'] = _IMAGEANNOTATION
DESCRIPTOR.message_types_by_name['ImageAnnotations'] = _IMAGEANNOTATIONS
DESCRIPTOR.enum_types_by_name['ImageFormats'] = _IMAGEFORMATS
DESCRIPTOR.enum_types_by_name['ColorSpaces'] = _COLORSPACES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), dict(
  DESCRIPTOR = _IMAGE,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.Image)
  ))
_sym_db.RegisterMessage(Image)

ImageFormat = _reflection.GeneratedProtocolMessageType('ImageFormat', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEFORMAT,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.ImageFormat)
  ))
_sym_db.RegisterMessage(ImageFormat)

Vertex = _reflection.GeneratedProtocolMessageType('Vertex', (_message.Message,), dict(
  DESCRIPTOR = _VERTEX,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.Vertex)
  ))
_sym_db.RegisterMessage(Vertex)

BoundingPoly = _reflection.GeneratedProtocolMessageType('BoundingPoly', (_message.Message,), dict(
  DESCRIPTOR = _BOUNDINGPOLY,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.BoundingPoly)
  ))
_sym_db.RegisterMessage(BoundingPoly)

Resolution = _reflection.GeneratedProtocolMessageType('Resolution', (_message.Message,), dict(
  DESCRIPTOR = _RESOLUTION,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.Resolution)
  ))
_sym_db.RegisterMessage(Resolution)

ColorSpace = _reflection.GeneratedProtocolMessageType('ColorSpace', (_message.Message,), dict(
  DESCRIPTOR = _COLORSPACE,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.ColorSpace)
  ))
_sym_db.RegisterMessage(ColorSpace)

ImageSettings = _reflection.GeneratedProtocolMessageType('ImageSettings', (_message.Message,), dict(
  DESCRIPTOR = _IMAGESETTINGS,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.ImageSettings)
  ))
_sym_db.RegisterMessage(ImageSettings)

ImageAnnotation = _reflection.GeneratedProtocolMessageType('ImageAnnotation', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEANNOTATION,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.ImageAnnotation)
  ))
_sym_db.RegisterMessage(ImageAnnotation)

ImageAnnotations = _reflection.GeneratedProtocolMessageType('ImageAnnotations', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEANNOTATIONS,
  __module__ = 'is_msgs.image_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.ImageAnnotations)
  ))
_sym_db.RegisterMessage(ImageAnnotations)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\rcom.is.visionP\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/tests.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from is_msgs import validate_pb2 as is__msgs_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/tests.proto',
  package='is.tests',
  syntax='proto3',
  serialized_pb=_b('\n\x13is_msgs/tests.proto\x12\x08is.tests\x1a\x16is_msgs/validate.proto\"s\n\x03\x46oo\x12$\n\x05myint\x18\x01 \x01(\x05\x42\x15\xba\xe9\xc0\x03\x10\x1a\x0e\x18\xd0\x0f(\xce\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\"\n\x07myfloat\x18\x02 \x01(\x02\x42\x11\xba\xe9\xc0\x03\x0c\n\n\x15\x9a\x99\x99>%\xcd\xcc\xcc=\x12\"\n\x08mydouble\x18\x03 \x01(\x01\x42\x10\xba\xe9\xc0\x03\x0b\x12\t\x19\xb4\xc8v\xbe\x9f\xaa@@\"B\n\x03\x42\x61r\x12\x1c\n\x05myfoo\x18\x01 \x01(\x0b\x32\r.is.tests.Foo\x12\x1d\n\x07myfloat\x18\x02 \x01(\x02\x42\x0c\xba\xe9\xc0\x03\x07\n\x05%\x00\x00\x80\xbf\"\x87\x02\n\x07Repeats\x12\x1b\n\x04\x66oos\x18\x01 \x03(\x0b\x32\r.is.tests.Foo\x12\'\n\x04\x66oo2\x18\x02 \x01(\x0b\x32\r.is.tests.FooB\n\xba\xe9\xc0\x03\x05\x8a\x01\x02\x10\x01\x12\"\n\x06int32s\x18\x03 \x03(\x05\x42\x12\xba\xe9\xc0\x03\r\x1a\x0b\x10\xf6\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\x07uint32s\x18\x04 \x03(\rB\t\xba\xe9\xc0\x03\x04*\x02 \n\x12\x1c\n\x06\x66loats\x18\x05 \x03(\x02\x42\x0c\xba\xe9\xc0\x03\x07\n\x05\x1d\x00\x00 \xc1\x12!\n\x07\x64oubles\x18\x06 \x03(\x01\x42\x10\xba\xe9\xc0\x03\x0b\x12\t)\x00\x00\x00\x00\x00\x00$\xc0\x12\x19\n\x06int64s\x18\x07 \x03(\x03\x42\t\xba\xe9\xc0\x03\x04\"\x02\x10\n\x12\x1a\n\x07uint64s\x18\x08 \x03(\x04\x42\t\xba\xe9\xc0\x03\x04\x32\x02 db\x06proto3')
  ,
  dependencies=[is__msgs_dot_validate__pb2.DESCRIPTOR,])




_FOO = _descriptor.Descriptor(
  name='Foo',
  full_name='is.tests.Foo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='myint', full_name='is.tests.Foo.myint', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\020\032\016\030\320\017(\316\377\377\377\377\377\377\377\377\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='myfloat', full_name='is.tests.Foo.myfloat', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\014\n\n\025\232\231\231>%\315\314\314=')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mydouble', full_name='is.tests.Foo.mydouble', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\013\022\t\031\264\310v\276\237\252@@')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=172,
)


_BAR = _descriptor.Descriptor(
  name='Bar',
  full_name='is.tests.Bar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='myfoo', full_name='is.tests.Bar.myfoo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='myfloat', full_name='is.tests.Bar.myfloat', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\007\n\005%\000\000\200\277')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=240,
)


_REPEATS = _descriptor.Descriptor(
  name='Repeats',
  full_name='is.tests.Repeats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='foos', full_name='is.tests.Repeats.foos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='foo2', full_name='is.tests.Repeats.foo2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\005\212\001\002\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int32s', full_name='is.tests.Repeats.int32s', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\r\032\013\020\366\377\377\377\377\377\377\377\377\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint32s', full_name='is.tests.Repeats.uint32s', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\004*\002 \n')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='floats', full_name='is.tests.Repeats.floats', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\007\n\005\035\000\000 \301')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doubles', full_name='is.tests.Repeats.doubles', index=5,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\013\022\t)\000\000\000\000\000\000$\300')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int64s', full_name='is.tests.Repeats.int64s', index=6,
      number=7, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\004\"\002\020\n')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint64s', full_name='is.tests.Repeats.uint64s', index=7,
      number=8, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\0042\002 d')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=506,
)

_BAR.fields_by_name['myfoo'].message_type = _FOO
_REPEATS.fields_by_name['foos'].message_type = _FOO
_REPEATS.fields_by_name['foo2'].message_type = _FOO
DESCRIPTOR.message_types_by_name['Foo'] = _FOO
DESCRIPTOR.message_types_by_name['Bar'] = _BAR
DESCRIPTOR.message_types_by_name['Repeats'] = _REPEATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Foo = _reflection.GeneratedProtocolMessageType('Foo', (_message.Message,), dict(
  DESCRIPTOR = _FOO,
  __module__ = 'is_msgs.tests_pb2'
  # @@protoc_insertion_point(class_scope:is.tests.Foo)
  ))
_sym_db.RegisterMessage(Foo)

Bar = _reflection.GeneratedProtocolMessageType('Bar', (_message.Message,), dict(
  DESCRIPTOR = _BAR,
  __module__ = 'is_msgs.tests_pb2'
  # @@protoc_insertion_point(class_scope:is.tests.Bar)
  ))
_sym_db.RegisterMessage(Bar)

Repeats = _reflection.GeneratedProtocolMessageType('Repeats', (_message.Message,), dict(
  DESCRIPTOR = _REPEATS,
  __module__ = 'is_msgs.tests_pb2'
  # @@protoc_insertion_point(class_scope:is.tests.Repeats)
  ))
_sym_db.RegisterMessage(Repeats)


_FOO.fields_by_name['myint'].has_options = True
_FOO.fields_by_name['myint']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\020\032\016\030\320\017(\316\377\377\377\377\377\377\377\377\001'))
_FOO.fields_by_name['myfloat'].has_options = True
_FOO.fields_by_name['myfloat']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\014\n\n\025\232\231\231>%\315\314\314='))
_FOO.fields_by_name['mydouble'].has_options = True
_FOO.fields_by_name['mydouble']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\013\022\t\031\264\310v\276\237\252@@'))
_BAR.fields_by_name['myfloat'].has_options = True
_BAR.fields_by_name['myfloat']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\007\n\005%\000\000\200\277'))
_REPEATS.fields_by_name['foo2'].has_options = True
_REPEATS.fields_by_name['foo2']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\005\212\001\002\020\001'))
_REPEATS.fields_by_name['int32s'].has_options = True
_REPEATS.fields_by_name['int32s']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\r\032\013\020\366\377\377\377\377\377\377\377\377\001'))
_REPEATS.fields_by_name['uint32s'].has_options = True
_REPEATS.fields_by_name['uint32s']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\004*\002 \n'))
_REPEATS.fields_by_name['floats'].has_options = True
_REPEATS.fields_by_name['floats']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\007\n\005\035\000\000 \301'))
_REPEATS.fields_by_name['doubles'].has_options = True
_REPEATS.fields_by_name['doubles']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\013\022\t)\000\000\000\000\000\000$\300'))
_REPEATS.fields_by_name['int64s'].has_options = True
_REPEATS.fields_by_name['int64s']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\004\"\002\020\n'))
_REPEATS.fields_by_name['uint64s'].has_options = True
_REPEATS.fields_by_name['uint64s']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\272\351\300\003\0042\002 d'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/power.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/power.proto',
  package='is.common',
  syntax='proto3',
  serialized_pb=_b('\n\x13is_msgs/power.proto\x12\tis.common\x1a\x1egoogle/protobuf/duration.proto\"\xbc\x03\n\tPowerInfo\x12\x0f\n\x07voltage\x18\x01 \x01(\x02\x12\x18\n\x10terminal_voltage\x18\x02 \x01(\x02\x12\x14\n\x0c\x63\x65ll_voltage\x18\x03 \x03(\x02\x12\x0e\n\x06\x63harge\x18\x04 \x01(\x02\x12\x10\n\x08\x63\x61pacity\x18\x05 \x01(\x02\x12.\n\x04type\x18\x06 \x01(\x0e\x32 .is.common.PowerInfo.BatteryType\x12\x32\n\x06status\x18\x07 \x01(\x0e\x32\".is.common.PowerInfo.BatteryStatus\x12)\n\x06uptime\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x61utonomy\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\"3\n\x0b\x42\x61tteryType\x12\x06\n\x02PB\x10\x00\x12\x08\n\x04NICD\x10\x01\x12\x08\n\x04NIMH\x10\x02\x12\x08\n\x04LIPO\x10\x03\"[\n\rBatteryStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x43HARGING\x10\x01\x12\x0f\n\x0b\x44ISCHARGING\x10\x02\x12\x0b\n\x07\x43HARGED\x10\x03\x12\x11\n\rNOT_CONNECTED\x10\x04\x42\x11\n\rcom.is.commonP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])



_POWERINFO_BATTERYTYPE = _descriptor.EnumDescriptor(
  name='BatteryType',
  full_name='is.common.PowerInfo.BatteryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PB', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NICD', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NIMH', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIPO', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=367,
  serialized_end=418,
)
_sym_db.RegisterEnumDescriptor(_POWERINFO_BATTERYTYPE)

_POWERINFO_BATTERYSTATUS = _descriptor.EnumDescriptor(
  name='BatteryStatus',
  full_name='is.common.PowerInfo.BatteryStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHARGING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISCHARGING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHARGED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_CONNECTED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=420,
  serialized_end=511,
)
_sym_db.RegisterEnumDescriptor(_POWERINFO_BATTERYSTATUS)


_POWERINFO = _descriptor.Descriptor(
  name='PowerInfo',
  full_name='is.common.PowerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='voltage', full_name='is.common.PowerInfo.voltage', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='terminal_voltage', full_name='is.common.PowerInfo.terminal_voltage', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_voltage', full_name='is.common.PowerInfo.cell_voltage', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='charge', full_name='is.common.PowerInfo.charge', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capacity', full_name='is.common.PowerInfo.capacity', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='is.common.PowerInfo.type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='is.common.PowerInfo.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uptime', full_name='is.common.PowerInfo.uptime', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='autonomy', full_name='is.common.PowerInfo.autonomy', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _POWERINFO_BATTERYTYPE,
    _POWERINFO_BATTERYSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=511,
)

_POWERINFO.fields_by_name['type'].enum_type = _POWERINFO_BATTERYTYPE
_POWERINFO.fields_by_name['status'].enum_type = _POWERINFO_BATTERYSTATUS
_POWERINFO.fields_by_name['uptime'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_POWERINFO.fields_by_name['autonomy'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_POWERINFO_BATTERYTYPE.containing_type = _POWERINFO
_POWERINFO_BATTERYSTATUS.containing_type = _POWERINFO
DESCRIPTOR.message_types_by_name['PowerInfo'] = _POWERINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PowerInfo = _reflection.GeneratedProtocolMessageType('PowerInfo', (_message.Message,), dict(
  DESCRIPTOR = _POWERINFO,
  __module__ = 'is_msgs.power_pb2'
  # @@protoc_insertion_point(class_scope:is.common.PowerInfo)
  ))
_sym_db.RegisterMessage(PowerInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\rcom.is.commonP\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/camera.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from is_msgs import common_pb2 as is__msgs_dot_common__pb2
from is_msgs import image_pb2 as is__msgs_dot_image__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/camera.proto',
  package='is.vision',
  syntax='proto3',
  serialized_pb=_b('\n\x14is_msgs/camera.proto\x12\tis.vision\x1a\x14is_msgs/common.proto\x1a\x13is_msgs/image.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"1\n\rCameraSetting\x12\x11\n\tautomatic\x18\x01 \x01(\x08\x12\r\n\x05ratio\x18\x02 \x01(\x02\"\xc9\x04\n\x0e\x43\x61meraSettings\x12,\n\nbrightness\x18\x01 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12*\n\x08\x65xposure\x18\x02 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\'\n\x05\x66ocus\x18\x03 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12&\n\x04gain\x18\x04 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\'\n\x05gamma\x18\x05 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12%\n\x03hue\x18\x06 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12&\n\x04iris\x18\x07 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12,\n\nsaturation\x18\x08 \x01(\x0b\x32\x18.is.vision.CameraSetting\x12+\n\tsharpness\x18\t \x01(\x0b\x32\x18.is.vision.CameraSetting\x12)\n\x07shutter\x18\n \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\x32\n\x10white_balance_bu\x18\x0b \x01(\x0b\x32\x18.is.vision.CameraSetting\x12\x32\n\x10white_balance_rv\x18\x0c \x01(\x0b\x32\x18.is.vision.CameraSetting\x12&\n\x04zoom\x18\r \x01(\x0b\x32\x18.is.vision.CameraSetting\"\x91\x01\n\x0c\x43\x61meraConfig\x12-\n\x08sampling\x18\x01 \x01(\x0b\x32\x1b.is.common.SamplingSettings\x12\'\n\x05image\x18\x02 \x01(\x0b\x32\x18.is.vision.ImageSettings\x12)\n\x06\x63\x61mera\x18\x03 \x01(\x0b\x32\x19.is.vision.CameraSettings\"\x8c\x02\n\x11\x43\x61meraCalibration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x31\n\rcalibrated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x03 \x01(\x01\x12)\n\nresolution\x18\x04 \x01(\x0b\x32\x15.is.vision.Resolution\x12$\n\tintrinsic\x18\x05 \x01(\x0b\x32\x11.is.common.Tensor\x12%\n\ndistortion\x18\x06 \x01(\x0b\x32\x11.is.common.Tensor\x12\x31\n\textrinsic\x18\x07 \x03(\x0b\x32\x1e.is.vision.FrameTransformation\"N\n\x13\x46rameTransformation\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\x12\x1d\n\x02tf\x18\x03 \x01(\x0b\x32\x11.is.common.Tensor*]\n\x12\x43\x61meraConfigFields\x12\x07\n\x03\x41LL\x10\x00\x12\x15\n\x11SAMPLING_SETTINGS\x10\x01\x12\x12\n\x0eIMAGE_SETTINGS\x10\x02\x12\x13\n\x0f\x43\x41MERA_SETTINGS\x10\x03\x42\x11\n\rcom.is.visionP\x01\x62\x06proto3')
  ,
  dependencies=[is__msgs_dot_common__pb2.DESCRIPTOR,is__msgs_dot_image__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_CAMERACONFIGFIELDS = _descriptor.EnumDescriptor(
  name='CameraConfigFields',
  full_name='is.vision.CameraConfigFields',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAMPLING_SETTINGS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_SETTINGS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMERA_SETTINGS', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1249,
  serialized_end=1342,
)
_sym_db.RegisterEnumDescriptor(_CAMERACONFIGFIELDS)

CameraConfigFields = enum_type_wrapper.EnumTypeWrapper(_CAMERACONFIGFIELDS)
ALL = 0
SAMPLING_SETTINGS = 1
IMAGE_SETTINGS = 2
CAMERA_SETTINGS = 3



_CAMERASETTING = _descriptor.Descriptor(
  name='CameraSetting',
  full_name='is.vision.CameraSetting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='automatic', full_name='is.vision.CameraSetting.automatic', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ratio', full_name='is.vision.CameraSetting.ratio', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=160,
)


_CAMERASETTINGS = _descriptor.Descriptor(
  name='CameraSettings',
  full_name='is.vision.CameraSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='brightness', full_name='is.vision.CameraSettings.brightness', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exposure', full_name='is.vision.CameraSettings.exposure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='focus', full_name='is.vision.CameraSettings.focus', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gain', full_name='is.vision.CameraSettings.gain', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gamma', full_name='is.vision.CameraSettings.gamma', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hue', full_name='is.vision.CameraSettings.hue', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iris', full_name='is.vision.CameraSettings.iris', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saturation', full_name='is.vision.CameraSettings.saturation', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sharpness', full_name='is.vision.CameraSettings.sharpness', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shutter', full_name='is.vision.CameraSettings.shutter', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='white_balance_bu', full_name='is.vision.CameraSettings.white_balance_bu', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='white_balance_rv', full_name='is.vision.CameraSettings.white_balance_rv', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zoom', full_name='is.vision.CameraSettings.zoom', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=748,
)


_CAMERACONFIG = _descriptor.Descriptor(
  name='CameraConfig',
  full_name='is.vision.CameraConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sampling', full_name='is.vision.CameraConfig.sampling', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='is.vision.CameraConfig.image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='camera', full_name='is.vision.CameraConfig.camera', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=896,
)


_CAMERACALIBRATION = _descriptor.Descriptor(
  name='CameraCalibration',
  full_name='is.vision.CameraCalibration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='is.vision.CameraCalibration.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calibrated_at', full_name='is.vision.CameraCalibration.calibrated_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='is.vision.CameraCalibration.error', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resolution', full_name='is.vision.CameraCalibration.resolution', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intrinsic', full_name='is.vision.CameraCalibration.intrinsic', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distortion', full_name='is.vision.CameraCalibration.distortion', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extrinsic', full_name='is.vision.CameraCalibration.extrinsic', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=899,
  serialized_end=1167,
)


_FRAMETRANSFORMATION = _descriptor.Descriptor(
  name='FrameTransformation',
  full_name='is.vision.FrameTransformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='is.vision.FrameTransformation.from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to', full_name='is.vision.FrameTransformation.to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tf', full_name='is.vision.FrameTransformation.tf', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1169,
  serialized_end=1247,
)

_CAMERASETTINGS.fields_by_name['brightness'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['exposure'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['focus'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['gain'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['gamma'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['hue'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['iris'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['saturation'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['sharpness'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['shutter'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['white_balance_bu'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['white_balance_rv'].message_type = _CAMERASETTING
_CAMERASETTINGS.fields_by_name['zoom'].message_type = _CAMERASETTING
_CAMERACONFIG.fields_by_name['sampling'].message_type = is__msgs_dot_common__pb2._SAMPLINGSETTINGS
_CAMERACONFIG.fields_by_name['image'].message_type = is__msgs_dot_image__pb2._IMAGESETTINGS
_CAMERACONFIG.fields_by_name['camera'].message_type = _CAMERASETTINGS
_CAMERACALIBRATION.fields_by_name['calibrated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CAMERACALIBRATION.fields_by_name['resolution'].message_type = is__msgs_dot_image__pb2._RESOLUTION
_CAMERACALIBRATION.fields_by_name['intrinsic'].message_type = is__msgs_dot_common__pb2._TENSOR
_CAMERACALIBRATION.fields_by_name['distortion'].message_type = is__msgs_dot_common__pb2._TENSOR
_CAMERACALIBRATION.fields_by_name['extrinsic'].message_type = _FRAMETRANSFORMATION
_FRAMETRANSFORMATION.fields_by_name['tf'].message_type = is__msgs_dot_common__pb2._TENSOR
DESCRIPTOR.message_types_by_name['CameraSetting'] = _CAMERASETTING
DESCRIPTOR.message_types_by_name['CameraSettings'] = _CAMERASETTINGS
DESCRIPTOR.message_types_by_name['CameraConfig'] = _CAMERACONFIG
DESCRIPTOR.message_types_by_name['CameraCalibration'] = _CAMERACALIBRATION
DESCRIPTOR.message_types_by_name['FrameTransformation'] = _FRAMETRANSFORMATION
DESCRIPTOR.enum_types_by_name['CameraConfigFields'] = _CAMERACONFIGFIELDS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CameraSetting = _reflection.GeneratedProtocolMessageType('CameraSetting', (_message.Message,), dict(
  DESCRIPTOR = _CAMERASETTING,
  __module__ = 'is_msgs.camera_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.CameraSetting)
  ))
_sym_db.RegisterMessage(CameraSetting)

CameraSettings = _reflection.GeneratedProtocolMessageType('CameraSettings', (_message.Message,), dict(
  DESCRIPTOR = _CAMERASETTINGS,
  __module__ = 'is_msgs.camera_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.CameraSettings)
  ))
_sym_db.RegisterMessage(CameraSettings)

CameraConfig = _reflection.GeneratedProtocolMessageType('CameraConfig', (_message.Message,), dict(
  DESCRIPTOR = _CAMERACONFIG,
  __module__ = 'is_msgs.camera_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.CameraConfig)
  ))
_sym_db.RegisterMessage(CameraConfig)

CameraCalibration = _reflection.GeneratedProtocolMessageType('CameraCalibration', (_message.Message,), dict(
  DESCRIPTOR = _CAMERACALIBRATION,
  __module__ = 'is_msgs.camera_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.CameraCalibration)
  ))
_sym_db.RegisterMessage(CameraCalibration)

FrameTransformation = _reflection.GeneratedProtocolMessageType('FrameTransformation', (_message.Message,), dict(
  DESCRIPTOR = _FRAMETRANSFORMATION,
  __module__ = 'is_msgs.camera_pb2'
  # @@protoc_insertion_point(class_scope:is.vision.FrameTransformation)
  ))
_sym_db.RegisterMessage(FrameTransformation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\rcom.is.visionP\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/common.proto',
  package='is.common',
  syntax='proto3',
  serialized_pb=_b('\n\x14is_msgs/common.proto\x12\tis.common\x1a\x1egoogle/protobuf/wrappers.proto\"n\n\x10SamplingSettings\x12.\n\tfrequency\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12*\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"N\n\x0bSyncRequest\x12\x10\n\x08\x65ntities\x18\x01 \x03(\t\x12-\n\x08sampling\x18\x02 \x01(\x0b\x32\x1b.is.common.SamplingSettings\"\x1f\n\rFieldSelector\x12\x0e\n\x06\x66ields\x18\x01 \x03(\r\"Z\n\x05Shape\x12(\n\x04\x64ims\x18\x01 \x03(\x0b\x32\x1a.is.common.Shape.Dimension\x1a\'\n\tDimension\x12\x0c\n\x04size\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x9d\x01\n\x06Tensor\x12\x1f\n\x05shape\x18\x01 \x01(\x0b\x32\x10.is.common.Shape\x12!\n\x04type\x18\x02 \x01(\x0e\x32\x13.is.common.DataType\x12\x12\n\x06\x66loats\x18\x03 \x03(\x02\x42\x02\x10\x01\x12\x13\n\x07\x64oubles\x18\x04 \x03(\x01\x42\x02\x10\x01\x12\x12\n\x06ints32\x18\x05 \x03(\x05\x42\x02\x10\x01\x12\x12\n\x06ints64\x18\x06 \x03(\x03\x42\x02\x10\x01\"+\n\x08Position\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"7\n\x0bOrientation\x12\x0b\n\x03yaw\x18\x01 \x01(\x02\x12\r\n\x05pitch\x18\x02 \x01(\x02\x12\x0c\n\x04roll\x18\x03 \x01(\x02\"Z\n\x04Pose\x12%\n\x08position\x18\x01 \x01(\x0b\x32\x13.is.common.Position\x12+\n\x0borientation\x18\x02 \x01(\x0b\x32\x16.is.common.Orientation\"(\n\x05Speed\x12\x0e\n\x06linear\x18\x01 \x01(\x02\x12\x0f\n\x07\x61ngular\x18\x02 \x01(\x02*]\n\x08\x44\x61taType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0e\n\nFLOAT_TYPE\x10\x01\x12\x0f\n\x0b\x44OUBLE_TYPE\x10\x02\x12\x0e\n\nINT32_TYPE\x10\x03\x12\x0e\n\nINT64_TYPE\x10\x04\x42\x11\n\rcom.is.commonP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='is.common.DataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_TYPE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT_TYPE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE_TYPE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT32_TYPE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT64_TYPE', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=780,
  serialized_end=873,
)
_sym_db.RegisterEnumDescriptor(_DATATYPE)

DataType = enum_type_wrapper.EnumTypeWrapper(_DATATYPE)
UNKNOWN_TYPE = 0
FLOAT_TYPE = 1
DOUBLE_TYPE = 2
INT32_TYPE = 3
INT64_TYPE = 4



_SAMPLINGSETTINGS = _descriptor.Descriptor(
  name='SamplingSettings',
  full_name='is.common.SamplingSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frequency', full_name='is.common.SamplingSettings.frequency', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delay', full_name='is.common.SamplingSettings.delay', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=177,
)


_SYNCREQUEST = _descriptor.Descriptor(
  name='SyncRequest',
  full_name='is.common.SyncRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entities', full_name='is.common.SyncRequest.entities', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='is.common.SyncRequest.sampling', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=257,
)


_FIELDSELECTOR = _descriptor.Descriptor(
  name='FieldSelector',
  full_name='is.common.FieldSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='is.common.FieldSelector.fields', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=290,
)


_SHAPE_DIMENSION = _descriptor.Descriptor(
  name='Dimension',
  full_name='is.common.Shape.Dimension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='is.common.Shape.Dimension.size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='is.common.Shape.Dimension.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=382,
)

_SHAPE = _descriptor.Descriptor(
  name='Shape',
  full_name='is.common.Shape',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dims', full_name='is.common.Shape.dims', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SHAPE_DIMENSION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=382,
)


_TENSOR = _descriptor.Descriptor(
  name='Tensor',
  full_name='is.common.Tensor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='is.common.Tensor.shape', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='is.common.Tensor.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='floats', full_name='is.common.Tensor.floats', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doubles', full_name='is.common.Tensor.doubles', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ints32', full_name='is.common.Tensor.ints32', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ints64', full_name='is.common.Tensor.ints64', index=5,
      number=6, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=542,
)


_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='is.common.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='is.common.Position.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='is.common.Position.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z', full_name='is.common.Position.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=587,
)


_ORIENTATION = _descriptor.Descriptor(
  name='Orientation',
  full_name='is.common.Orientation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='yaw', full_name='is.common.Orientation.yaw', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pitch', full_name='is.common.Orientation.pitch', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roll', full_name='is.common.Orientation.roll', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=589,
  serialized_end=644,
)


_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='is.common.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='is.common.Pose.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='is.common.Pose.orientation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=736,
)


_SPEED = _descriptor.Descriptor(
  name='Speed',
  full_name='is.common.Speed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear', full_name='is.common.Speed.linear', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angular', full_name='is.common.Speed.angular', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=778,
)

_SAMPLINGSETTINGS.fields_by_name['frequency'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_SAMPLINGSETTINGS.fields_by_name['delay'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_SYNCREQUEST.fields_by_name['sampling'].message_type = _SAMPLINGSETTINGS
_SHAPE_DIMENSION.containing_type = _SHAPE
_SHAPE.fields_by_name['dims'].message_type = _SHAPE_DIMENSION
_TENSOR.fields_by_name['shape'].message_type = _SHAPE
_TENSOR.fields_by_name['type'].enum_type = _DATATYPE
_POSE.fields_by_name['position'].message_type = _POSITION
_POSE.fields_by_name['orientation'].message_type = _ORIENTATION
DESCRIPTOR.message_types_by_name['SamplingSettings'] = _SAMPLINGSETTINGS
DESCRIPTOR.message_types_by_name['SyncRequest'] = _SYNCREQUEST
DESCRIPTOR.message_types_by_name['FieldSelector'] = _FIELDSELECTOR
DESCRIPTOR.message_types_by_name['Shape'] = _SHAPE
DESCRIPTOR.message_types_by_name['Tensor'] = _TENSOR
DESCRIPTOR.message_types_by_name['Position'] = _POSITION
DESCRIPTOR.message_types_by_name['Orientation'] = _ORIENTATION
DESCRIPTOR.message_types_by_name['Pose'] = _POSE
DESCRIPTOR.message_types_by_name['Speed'] = _SPEED
DESCRIPTOR.enum_types_by_name['DataType'] = _DATATYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SamplingSettings = _reflection.GeneratedProtocolMessageType('SamplingSettings', (_message.Message,), dict(
  DESCRIPTOR = _SAMPLINGSETTINGS,
  __module__ = 'is_msgs.common_pb2'
  # @@protoc_insertion_point(class_scope:is.common.SamplingSettings)
  ))
_sym_db.RegisterMessage(SamplingSettings)

SyncRequest = _reflection.GeneratedProtocolMessageType('SyncRequest', (_message.Message,), dict(
  DESCRIPTOR = _SYNCREQUEST,
  __module__ = 'is_msgs.common_pb2'
  # @@protoc_insertion_point(class_scope:is.common.SyncRequest)
  ))
_sym_db.RegisterMessage(SyncRequest)

FieldSelector = _reflection.GeneratedProtocolMessageType('FieldSelector', (_message.Message,), dict(
  DESCRIPTOR = _FIELDSELECTOR,
  __module__ = 'is_msgs.common_pb2'
  # @@protoc_insertion_point(class_scope:is.common.FieldSelector)
  ))
_sym_db.RegisterMessage(FieldSelector)

Shape = _reflection.GeneratedProtocolMessageType('Shape', (_message.Message,), dict(

  Dimension = _reflection.GeneratedProtocolMessageType('Dimension', (_message.Message,), dict(
    DESCRIPTOR = _SHAPE_DIMENSION,
    __module__ = 'is_msgs.common_pb2'
    # @@protoc_insertion_point(class_scope:is.common.Shape.Dimension)
    ))
  ,
  DESCRIPTOR = _SHAPE,
  __module__ = 'is_msgs.common_pb2'
  # @@protoc_insertion_point(class_scope:is.common.Shape)
  ))
_sym_db.RegisterMessage(Shape)
_sym_db.RegisterMessage(Shape.Dimension)

Tensor = _reflection.GeneratedProtocolMessageType('Tensor', (_message.Message,), dict(
  DESCRIPTOR = _TENSOR,
  __module__ = 'is_msgs.common_pb2'
  # @@protoc_insertion_point(class_scope:is.common.Tensor)
  ))
_sym_db.RegisterMessage(Tensor)

Position = _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), dict(
  DESCRIPTOR = _POSITION,
  __module__ = 'is_msgs.common_pb2'
  # @@protoc_insertion_point(class_scope:is.common.Position)
  ))
_sym_db.RegisterMessage(Position)

Orientation = _reflection.GeneratedProtocolMessageType('Orientation', (_message.Message,), dict(
  DESCRIPTOR = _ORIENTATION,
  __module__ = 'is_msgs.common_pb2'
  # @@protoc_insertion_point(class_scope:is.common.Orientation)
  ))
_sym_db.RegisterMessage(Orientation)

Pose = _reflection.GeneratedProtocolMessageType('Pose', (_message.Message,), dict(
  DESCRIPTOR = _POSE,
  __module__ = 'is_msgs.common_pb2'
  # @@protoc_insertion_point(class_scope:is.common.Pose)
  ))
_sym_db.RegisterMessage(Pose)

Speed = _reflection.GeneratedProtocolMessageType('Speed', (_message.Message,), dict(
  DESCRIPTOR = _SPEED,
  __module__ = 'is_msgs.common_pb2'
  # @@protoc_insertion_point(class_scope:is.common.Speed)
  ))
_sym_db.RegisterMessage(Speed)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\rcom.is.commonP\001'))
_TENSOR.fields_by_name['floats'].has_options = True
_TENSOR.fields_by_name['floats']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TENSOR.fields_by_name['doubles'].has_options = True
_TENSOR.fields_by_name['doubles']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TENSOR.fields_by_name['ints32'].has_options = True
_TENSOR.fields_by_name['ints32']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_TENSOR.fields_by_name['ints64'].has_options = True
_TENSOR.fields_by_name['ints64']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/wire.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/wire.proto',
  package='is.wire',
  syntax='proto3',
  serialized_pb=_b('\n\x12is_msgs/wire.proto\x12\x07is.wire\x1a\x19google/protobuf/any.proto\"8\n\x06Status\x12!\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x13.is.wire.StatusCode\x12\x0b\n\x03why\x18\x02 \x01(\t\"\xeb\x01\n\nWireFormat\x12\r\n\x03raw\x18\x01 \x01(\x0cH\x00\x12\'\n\x07message\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x12\n\ncreated_at\x18\x03 \x01(\x04\x12*\n\x0c\x63ontent_type\x18\x04 \x01(\x0e\x32\x14.is.wire.ContentType\x12\x1f\n\x06status\x18\x05 \x01(\x0b\x32\x0f.is.wire.Status\x12\x16\n\x0e\x63orrelation_id\x18\x06 \x01(\x04\x12\x10\n\x08reply_to\x18\x07 \x01(\t\x12\x12\n\nexpires_in\x18\x08 \x01(\rB\x06\n\x04\x62ody*\xfe\x01\n\nStatusCode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x13\n\x0fUNAUTHENTICATED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x10\n\x0cOUT_OF_RANGE\x10\n\x12\x11\n\rUNIMPLEMENTED\x10\x0b\x12\x12\n\x0eINTERNAL_ERROR\x10\x0c*>\n\x0b\x43ontentType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08PROTOBUF\x10\x01\x12\x08\n\x04JSON\x10\x02\x12\r\n\tPROTOTEXT\x10\x03\x42\x0f\n\x0b\x63om.is.wireP\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_STATUSCODE = _descriptor.EnumDescriptor(
  name='StatusCode',
  full_name='is.wire.StatusCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ARGUMENT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEADLINE_EXCEEDED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_EXISTS', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_DENIED', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNAUTHENTICATED', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_PRECONDITION', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_RANGE', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIMPLEMENTED', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=12, number=12,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=355,
  serialized_end=609,
)
_sym_db.RegisterEnumDescriptor(_STATUSCODE)

StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
_CONTENTTYPE = _descriptor.EnumDescriptor(
  name='ContentType',
  full_name='is.wire.ContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROTOBUF', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROTOTEXT', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=611,
  serialized_end=673,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
UNKNOWN = 0
OK = 1
CANCELLED = 2
INVALID_ARGUMENT = 3
DEADLINE_EXCEEDED = 4
NOT_FOUND = 5
ALREADY_EXISTS = 6
PERMISSION_DENIED = 7
UNAUTHENTICATED = 8
FAILED_PRECONDITION = 9
OUT_OF_RANGE = 10
UNIMPLEMENTED = 11
INTERNAL_ERROR = 12
NONE = 0
PROTOBUF = 1
JSON = 2
PROTOTEXT = 3



_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='is.wire.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='is.wire.Status.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='why', full_name='is.wire.Status.why', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=114,
)


_WIREFORMAT = _descriptor.Descriptor(
  name='WireFormat',
  full_name='is.wire.WireFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='is.wire.WireFormat.raw', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='is.wire.WireFormat.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='is.wire.WireFormat.created_at', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='is.wire.WireFormat.content_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='is.wire.WireFormat.status', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='correlation_id', full_name='is.wire.WireFormat.correlation_id', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reply_to', full_name='is.wire.WireFormat.reply_to', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='is.wire.WireFormat.expires_in', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='is.wire.WireFormat.body',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=117,
  serialized_end=352,
)

_STATUS.fields_by_name['code'].enum_type = _STATUSCODE
_WIREFORMAT.fields_by_name['message'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_WIREFORMAT.fields_by_name['content_type'].enum_type = _CONTENTTYPE
_WIREFORMAT.fields_by_name['status'].message_type = _STATUS
_WIREFORMAT.oneofs_by_name['body'].fields.append(
  _WIREFORMAT.fields_by_name['raw'])
_WIREFORMAT.fields_by_name['raw'].containing_oneof = _WIREFORMAT.oneofs_by_name['body']
_WIREFORMAT.oneofs_by_name['body'].fields.append(
  _WIREFORMAT.fields_by_name['message'])
_WIREFORMAT.fields_by_name['message'].containing_oneof = _WIREFORMAT.oneofs_by_name['body']
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.message_types_by_name['WireFormat'] = _WIREFORMAT
DESCRIPTOR.enum_types_by_name['StatusCode'] = _STATUSCODE
DESCRIPTOR.enum_types_by_name['ContentType'] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), dict(
  DESCRIPTOR = _STATUS,
  __module__ = 'is_msgs.wire_pb2'
  # @@protoc_insertion_point(class_scope:is.wire.Status)
  ))
_sym_db.RegisterMessage(Status)

WireFormat = _reflection.GeneratedProtocolMessageType('WireFormat', (_message.Message,), dict(
  DESCRIPTOR = _WIREFORMAT,
  __module__ = 'is_msgs.wire_pb2'
  # @@protoc_insertion_point(class_scope:is.wire.WireFormat)
  ))
_sym_db.RegisterMessage(WireFormat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\013com.is.wireP\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: is_msgs/robot.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from is_msgs import common_pb2 as is__msgs_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='is_msgs/robot.proto',
  package='is.robot',
  syntax='proto3',
  serialized_pb=_b('\n\x13is_msgs/robot.proto\x12\x08is.robot\x1a\x14is_msgs/common.proto\".\n\x0bRobotConfig\x12\x1f\n\x05speed\x18\x01 \x01(\x0b\x32\x10.is.common.Speed\".\n\rFinalPoseTask\x12\x1d\n\x04goal\x18\x01 \x01(\x0b\x32\x0f.is.common.Pose\"2\n\x08PathTask\x12&\n\tpositions\x18\x01 \x03(\x0b\x32\x13.is.common.Position\"Z\n\x0eTrajectoryTask\x12&\n\tpositions\x18\x01 \x03(\x0b\x32\x13.is.common.Position\x12 \n\x06speeds\x18\x02 \x03(\x0b\x32\x10.is.common.Speed\"\xd6\x01\n\tRobotTask\x12\'\n\x04pose\x18\x01 \x01(\x0b\x32\x17.is.robot.FinalPoseTaskH\x00\x12\"\n\x04path\x18\x02 \x01(\x0b\x32\x12.is.robot.PathTaskH\x00\x12.\n\ntrajectory\x18\x03 \x01(\x0b\x32\x18.is.robot.TrajectoryTaskH\x00\x12\x15\n\rallowed_error\x18\x0e \x01(\x02\x12-\n\x08sampling\x18\x0f \x01(\x0b\x32\x1b.is.common.SamplingSettingsB\x06\n\x04Task\"\xbe\x01\n\x17RobotControllerProgress\x12\'\n\rcurrent_speed\x18\x01 \x01(\x0b\x32\x10.is.common.Speed\x12%\n\x0c\x63urrent_pose\x18\x02 \x01(\x0b\x32\x0f.is.common.Pose\x12%\n\x0c\x64\x65sired_pose\x18\x03 \x01(\x0b\x32\x0f.is.common.Pose\x12\r\n\x05\x65rror\x18\x04 \x01(\x02\x12\x0c\n\x04\x64one\x18\x05 \x01(\x08\x12\x0f\n\x07sources\x18\x06 \x01(\x05\x42\x10\n\x0c\x63om.is.robotP\x01\x62\x06proto3')
  ,
  dependencies=[is__msgs_dot_common__pb2.DESCRIPTOR,])




_ROBOTCONFIG = _descriptor.Descriptor(
  name='RobotConfig',
  full_name='is.robot.RobotConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed', full_name='is.robot.RobotConfig.speed', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=101,
)


_FINALPOSETASK = _descriptor.Descriptor(
  name='FinalPoseTask',
  full_name='is.robot.FinalPoseTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='goal', full_name='is.robot.FinalPoseTask.goal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=149,
)


_PATHTASK = _descriptor.Descriptor(
  name='PathTask',
  full_name='is.robot.PathTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='positions', full_name='is.robot.PathTask.positions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=201,
)


_TRAJECTORYTASK = _descriptor.Descriptor(
  name='TrajectoryTask',
  full_name='is.robot.TrajectoryTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='positions', full_name='is.robot.TrajectoryTask.positions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speeds', full_name='is.robot.TrajectoryTask.speeds', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=293,
)


_ROBOTTASK = _descriptor.Descriptor(
  name='RobotTask',
  full_name='is.robot.RobotTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='is.robot.RobotTask.pose', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='is.robot.RobotTask.path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trajectory', full_name='is.robot.RobotTask.trajectory', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allowed_error', full_name='is.robot.RobotTask.allowed_error', index=3,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='is.robot.RobotTask.sampling', index=4,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Task', full_name='is.robot.RobotTask.Task',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=296,
  serialized_end=510,
)


_ROBOTCONTROLLERPROGRESS = _descriptor.Descriptor(
  name='RobotControllerProgress',
  full_name='is.robot.RobotControllerProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_speed', full_name='is.robot.RobotControllerProgress.current_speed', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_pose', full_name='is.robot.RobotControllerProgress.current_pose', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='desired_pose', full_name='is.robot.RobotControllerProgress.desired_pose', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='is.robot.RobotControllerProgress.error', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='done', full_name='is.robot.RobotControllerProgress.done', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sources', full_name='is.robot.RobotControllerProgress.sources', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=703,
)

_ROBOTCONFIG.fields_by_name['speed'].message_type = is__msgs_dot_common__pb2._SPEED
_FINALPOSETASK.fields_by_name['goal'].message_type = is__msgs_dot_common__pb2._POSE
_PATHTASK.fields_by_name['positions'].message_type = is__msgs_dot_common__pb2._POSITION
_TRAJECTORYTASK.fields_by_name['positions'].message_type = is__msgs_dot_common__pb2._POSITION
_TRAJECTORYTASK.fields_by_name['speeds'].message_type = is__msgs_dot_common__pb2._SPEED
_ROBOTTASK.fields_by_name['pose'].message_type = _FINALPOSETASK
_ROBOTTASK.fields_by_name['path'].message_type = _PATHTASK
_ROBOTTASK.fields_by_name['trajectory'].message_type = _TRAJECTORYTASK
_ROBOTTASK.fields_by_name['sampling'].message_type = is__msgs_dot_common__pb2._SAMPLINGSETTINGS
_ROBOTTASK.oneofs_by_name['Task'].fields.append(
  _ROBOTTASK.fields_by_name['pose'])
_ROBOTTASK.fields_by_name['pose'].containing_oneof = _ROBOTTASK.oneofs_by_name['Task']
_ROBOTTASK.oneofs_by_name['Task'].fields.append(
  _ROBOTTASK.fields_by_name['path'])
_ROBOTTASK.fields_by_name['path'].containing_oneof = _ROBOTTASK.oneofs_by_name['Task']
_ROBOTTASK.oneofs_by_name['Task'].fields.append(
  _ROBOTTASK.fields_by_name['trajectory'])
_ROBOTTASK.fields_by_name['trajectory'].containing_oneof = _ROBOTTASK.oneofs_by_name['Task']
_ROBOTCONTROLLERPROGRESS.fields_by_name['current_speed'].message_type = is__msgs_dot_common__pb2._SPEED
_ROBOTCONTROLLERPROGRESS.fields_by_name['current_pose'].message_type = is__msgs_dot_common__pb2._POSE
_ROBOTCONTROLLERPROGRESS.fields_by_name['desired_pose'].message_type = is__msgs_dot_common__pb2._POSE
DESCRIPTOR.message_types_by_name['RobotConfig'] = _ROBOTCONFIG
DESCRIPTOR.message_types_by_name['FinalPoseTask'] = _FINALPOSETASK
DESCRIPTOR.message_types_by_name['PathTask'] = _PATHTASK
DESCRIPTOR.message_types_by_name['TrajectoryTask'] = _TRAJECTORYTASK
DESCRIPTOR.message_types_by_name['RobotTask'] = _ROBOTTASK
DESCRIPTOR.message_types_by_name['RobotControllerProgress'] = _ROBOTCONTROLLERPROGRESS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RobotConfig = _reflection.GeneratedProtocolMessageType('RobotConfig', (_message.Message,), dict(
  DESCRIPTOR = _ROBOTCONFIG,
  __module__ = 'is_msgs.robot_pb2'
  # @@protoc_insertion_point(class_scope:is.robot.RobotConfig)
  ))
_sym_db.RegisterMessage(RobotConfig)

FinalPoseTask = _reflection.GeneratedProtocolMessageType('FinalPoseTask', (_message.Message,), dict(
  DESCRIPTOR = _FINALPOSETASK,
  __module__ = 'is_msgs.robot_pb2'
  # @@protoc_insertion_point(class_scope:is.robot.FinalPoseTask)
  ))
_sym_db.RegisterMessage(FinalPoseTask)

PathTask = _reflection.GeneratedProtocolMessageType('PathTask', (_message.Message,), dict(
  DESCRIPTOR = _PATHTASK,
  __module__ = 'is_msgs.robot_pb2'
  # @@protoc_insertion_point(class_scope:is.robot.PathTask)
  ))
_sym_db.RegisterMessage(PathTask)

TrajectoryTask = _reflection.GeneratedProtocolMessageType('TrajectoryTask', (_message.Message,), dict(
  DESCRIPTOR = _TRAJECTORYTASK,
  __module__ = 'is_msgs.robot_pb2'
  # @@protoc_insertion_point(class_scope:is.robot.TrajectoryTask)
  ))
_sym_db.RegisterMessage(TrajectoryTask)

RobotTask = _reflection.GeneratedProtocolMessageType('RobotTask', (_message.Message,), dict(
  DESCRIPTOR = _ROBOTTASK,
  __module__ = 'is_msgs.robot_pb2'
  # @@protoc_insertion_point(class_scope:is.robot.RobotTask)
  ))
_sym_db.RegisterMessage(RobotTask)

RobotControllerProgress = _reflection.GeneratedProtocolMessageType('RobotControllerProgress', (_message.Message,), dict(
  DESCRIPTOR = _ROBOTCONTROLLERPROGRESS,
  __module__ = 'is_msgs.robot_pb2'
  # @@protoc_insertion_point(class_scope:is.robot.RobotControllerProgress)
  ))
_sym_db.RegisterMessage(RobotControllerProgress)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\014com.is.robotP\001'))
# @@protoc_insertion_point(module_scope)



from setuptools import setup

setup(
    name='is_msgs',
    version='1.1.4',
    description='Package with standard IS messages',
    url='http://github.com/labviros/is-msgs',
    author='labviros',
    license='MIT',
    packages=['is_msgs', 'is_msgs.utils'],
    package_data={ 'is_msgs': ['*.proto'] },
    zip_safe=False,
    install_requires=[ 'protobuf' ]
)


from __future__ import print_function
import os
import re
import sys
import shutil
import subprocess
import is_msgs

def get_include():
    return os.path.split(os.path.dirname(is_msgs.__file__))[0]

if __name__ == '__main__':
    if len(sys.argv) < 2:
        print('Nothing to do. No *.proto files passed on arguments. Exiting...')
        sys.exit(-1)    
    for arg in sys.argv[1:]:
        if not arg.endswith('.proto'):
            print('\'{}\' isn\'t a *.proto file. Exiting...'.format(arg))
            sys.exit(-1)
        if not os.path.exists(arg):
            print('\'{}\' file doesn\'t exist. Exiting...'.format(arg))
            sys.exit(-1)
    
    if os.path.exists('tmp/'):
        shutil.rmtree('tmp/', ignore_errors=True)
    os.makedirs('tmp/')
    
    for proto in sys.argv[1:]:
        shutil.copy(proto, 'tmp/')
        with open(os.path.join('tmp/', proto), 'r') as f:
            output = re.sub(r'import "is/msgs/*', r'import "is_msgs/', f.read())
        with open(os.path.join('tmp/', proto), 'w') as f:
            f.write(output)
    
    protos = ' '.join([os.path.join('tmp/', proto) for proto in sys.argv[1:]])
    protoc_command='protoc -I=tmp/ -I={} --python_out=. {}'.format(get_include(), protos)
    subprocess.call(['bash', '-c', protoc_command])
    shutil.rmtree('tmp/', ignore_errors=True)
